/*
 * file AuthenticationDemo.java
 *
 * Licensed Materials - Property of IBM
 * Restricted Materials of IBM - you are allowed to copy, modify and 
 * redistribute this file as part of any program that interfaces with 
 * IBM Rational CM API.
 *
 * com.ibm.rational.stp.client.samples.cc.AuthenticationDemo
 *
 * (C) Copyright IBM Corporation 2008.  All Rights Reserved.
 * Note to U.S. Government Users Restricted Rights:  Use, duplication or 
 * disclosure restricted by GSA ADP  Schedule Contract with IBM Corp.
 */

package com.ibm.rational.stp.client.samples.cc;

import javax.wvcm.ProviderFactory;
import javax.wvcm.WvcmException;
import javax.wvcm.ProviderFactory.Callback;
import javax.wvcm.WvcmException.ReasonCode;

import com.ibm.rational.wvcm.stp.StpProvider;
import com.ibm.rational.wvcm.stp.cc.CcProvider;

/**
 * Demonstrate basic CM Server authentication, including use of the
 * javax.wvcm.ProviderFactory.Callback authentication callback interface.
 */
public class AuthenticationDemo extends CcDemoBase {

    public class DemoCallback implements Callback {

        public Authentication getAuthentication(String realm, int retryCount)
            throws WvcmException
        {
            trace("Getting credentials for: " + realm);
            if (retryCount > 0) {
                throw new WvcmException("Invalid credentials", ReasonCode.UNAUTHORIZED);
            }
            return new Authentication() {
                public String loginName() {
                    return props().getLoginNameAndDomain();
                }
                public String password() {
                    return props().getPassword();
                }
            };
        }
    }

    /* (non-Javadoc)
     * @see junit.framework.TestCase#setUp()
     */
    protected void setUp() throws Exception {
        super.setUp();
    }

    /* (non-Javadoc)
     * @see junit.framework.TestCase#tearDown()
     */
    protected void tearDown() throws Exception {
        super.tearDown();
    }

    public void testCallback() throws Exception {

        // Instantiate our own authentication callback.
        Callback callback = new DemoCallback();

        // Instantiate our own CcProvider so we can specify our own callback.
        StpProvider stpProvider =
            (StpProvider) ProviderFactory.createProvider(
                CcProvider.CC_ONLY_PROVIDER_CLASS, callback);
        stpProvider.setServerUrl(props().getCmServerUrl());

        // Now perform an operation that requires a CM server connection.
        // This will cause our authentication callback to be invoked.
        CcProvider ccProvider = stpProvider.ccProvider();
        ccProvider.doGetDefaultCcRegistryRegion(null);
    }
}
